@@ -5,9 +5,12 @@
  *  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
+#include <QApplication>
+#include <QClipboard>
 #include <QDir>
 #include <QFileInfo>
 #include <QNetworkInterface>
+#include <QProcess>
 #include <QStandardPaths>
 #include <QString>
 
@@ -17,7 +20,6 @@
 
 #include <KDesktopFile>
 #include <KIO/ApplicationLauncherJob>
-#include <KIO/CommandLauncherJob>
 #include <KLocalizedString>
 #include <KNotificationJobUiDelegate>
 #include <KOSRelease>
@@ -42,7 +44,8 @@ Controller::Controller()
         m_releaseUrl = QStringLiteral("https://invent.kde.org/groups/plasma/-/activity");
     } else {
         // Release version
-        m_releaseUrl = QStringLiteral("https://kde.org/announcements/megarelease/6/?source=plasma-welcome");
+        m_releaseUrl = QStringLiteral("https://kde.org/announcements/plasma/%1/%1.%2.0/?source=plasma-welcome")
+                           .arg(QString::number(m_version.majorVersion()), QString::number(m_version.minorVersion()));
     }
 
     // Shown version string, matching desktop preview banner
@@ -120,19 +123,63 @@ void Controller::launchApp(const QString &program)
     job->start();
 }
 
-void Controller::runCommand(const QString &command)
+void Controller::runCommand(const QString &command, QJSValue callback)
 {
-    runCommand(command, QString());
+    const bool resultHandled = callback.isCallable();
+
+    QStringList args = command.split(QLatin1String(" "));
+    const QString program = args.first();
+
+    if (QStandardPaths::findExecutable(program).isEmpty()) {
+        const QString errorMessage = xi18nc("@info:progress", "The command <command>%1</command> could not be found.", program);
+
+        qWarning() << errorMessage;
+        if (resultHandled) {
+            callback.call({-1, errorMessage});
+        }
+        return;
+    }
+
+    args.removeFirst();
+
+    QProcess *process = new QProcess(this);
+    process->start(program, args);
+
+    if (!resultHandled) {
+        return;
+    }
+
+    connect(process, &QProcess::finished, [=](int exitCode, QProcess::ExitStatus exitStatus) {
+        const QString stdout = QString(process->readAllStandardOutput().trimmed());
+
+        // Success
+        if (exitCode == 0 && exitStatus == QProcess::NormalExit) {
+            callback.call({exitCode, stdout});
+            return;
+        }
+
+        // Failure
+        QString intermediateText = QString(process->readAllStandardError().trimmed());
+        if (intermediateText.isEmpty()) {
+            intermediateText = stdout;
+            if (intermediateText.isEmpty()) {
+                intermediateText = i18nc("@info:progress", "No error message provided");
+            }
+        }
+        const QString finalOutputText = xi18nc("@info:progress %1 is the command being run, and %2 is the human-readable error text returned by the command",
+                                               "The command <command>%1</command> failed: %2",
+                                               command,
+                                               intermediateText);
+
+        qWarning() << finalOutputText;
+        callback.call({exitCode, finalOutputText});
+        return;
+    });
 }
 
-void Controller::runCommand(const QString &command, const QString &desktopFilename)
+void Controller::copyToClipboard(const QString &text)
 {
-    auto *job = new KIO::CommandLauncherJob(command);
-    if (!desktopFilename.isEmpty()) {
-        job->setDesktopName(desktopFilename);
-    }
-    job->setUiDelegate(new KNotificationJobUiDelegate(KJobUiDelegate::AutoErrorHandlingEnabled));
-    job->start();
+    QApplication::clipboard()->setText(text);
 }
 
 bool Controller::networkAlreadyConnected()
@@ -191,6 +238,16 @@ QString Controller::distroUrl()
     return KOSRelease().homeUrl();
 }
 
+QString Controller::distroBugReportUrl()
+{
+    return KOSRelease().bugReportUrl();
+}
+
+KAboutData Controller::aboutData() const
+{
+    return KAboutData::applicationData();
+}
+
 void Controller::setMode(Mode mode)
 {
     if (m_mode == mode) {
