@@ -7,7 +7,8 @@
 
 #pragma once
 
-#include "plasma-welcome-version.h"
+#include <KAboutData>
+#include <QJSValue>
 #include <QObject>
 #include <QVersionNumber>
 #include <qqmlregistration.h>
@@ -22,16 +23,18 @@ public:
     Controller();
 
     Q_INVOKABLE static void launchApp(const QString &program);
-    Q_INVOKABLE static void runCommand(const QString &command);
-    Q_INVOKABLE static void runCommand(const QString &command, const QString &desktopFilename);
+    Q_INVOKABLE void runCommand(const QString &command, QJSValue callback = QJSValue());
+    Q_INVOKABLE static void copyToClipboard(const QString &text);
     Q_INVOKABLE bool networkAlreadyConnected();
     Q_INVOKABLE bool userFeedbackAvailable();
     Q_INVOKABLE QStringList distroPages();
     Q_INVOKABLE QString distroName();
     Q_INVOKABLE QString distroIcon();
     Q_INVOKABLE QString distroUrl();
+    Q_INVOKABLE QString distroBugReportUrl();
     Q_INVOKABLE QString installPrefix();
 
+    Q_PROPERTY(KAboutData aboutData READ aboutData CONSTANT)
     Q_PROPERTY(Mode mode MEMBER m_mode CONSTANT)
     Q_PROPERTY(QString shownVersion MEMBER m_shownVersion CONSTANT)
     Q_PROPERTY(int patchVersion MEMBER m_patchVersion CONSTANT)
@@ -44,6 +47,7 @@ public:
     enum Mode { Update, Beta, Live, Welcome };
     Q_ENUM(Mode)
 
+    KAboutData aboutData() const;
     void setMode(Mode mode);
 
 Q_SIGNALS:
